#[repr(transparent)]pub struct MatchH(pub u32);Expand description
Match High Register
Tuple Fields
0: u32Implementations
Sourceimpl MatchH
impl MatchH
Sourcepub const fn match_value(&self) -> u16
pub const fn match_value(&self) -> u16
The value written (upper 10 bits) to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled.
Sourcepub const fn set_match_value(&mut self, val: u16)
pub const fn set_match_value(&mut self, val: u16)
The value written (upper 10 bits) to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled.