#[repr(transparent)]pub struct MatchL(pub u32);Expand description
Match Low Register
Tuple Fields
0: u32Implementations
Sourceimpl MatchL
impl MatchL
Sourcepub const fn match_value(&self) -> u32
pub const fn match_value(&self) -> u32
The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled.
Sourcepub const fn set_match_value(&mut self, val: u32)
pub const fn set_match_value(&mut self, val: u32)
The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled.